searchData={"items":[{"type":"module","title":"Readability","doc":"Readability library for extracting & curating articles.","ref":"Readability.html"},{"type":"module","title":"Example - Readability","doc":"```elixir\n@type html :: binary\n\n# Just pass url\n%Readability.Summary{title: title, authors: authors, article_html: article} = Readability.summarize(url)\n\n# Extract title\nReadability.title(html)\n\n# Extract authors.\nReadability.authors(html)\n\n# Extract only text from article\narticle = html\n          |> Readability.article\n          |> Readability.readable_text\n\n# Extract article with transformed html\narticle = html\n          |> Readability.article\n          |> Readability.raw_html\n```","ref":"Readability.html#module-example"},{"type":"function","title":"Readability.article/2","doc":"Using a variety of metrics (content score, classname, element types), find the content that is\nmost likely to be the stuff a user wants to read.","ref":"Readability.html#article/2"},{"type":"function","title":"Example - Readability.article/2","doc":"iex> article_tree = Redability(html_str)\n    # returns article that is tuple","ref":"Readability.html#article/2-example"},{"type":"function","title":"Readability.authors/1","doc":"Extract authors.","ref":"Readability.html#authors/1"},{"type":"function","title":"Example - Readability.authors/1","doc":"iex> authors = Readability.authors(html_str)\n    [\"José Valim\", \"chrismccord\"]","ref":"Readability.html#authors/1-example"},{"type":"function","title":"Readability.default_options/0","doc":"","ref":"Readability.html#default_options/0"},{"type":"function","title":"Readability.is_response_markup/1","doc":"Returns true if Content-Type in provided headers list is a markup type,\nelse false.","ref":"Readability.html#is_response_markup/1"},{"type":"function","title":"Example - Readability.is_response_markup/1","doc":"iex> Readability.is_response_markup?([{\"Content-Type\", \"text/html\"}])\n    true","ref":"Readability.html#is_response_markup/1-example"},{"type":"function","title":"Readability.mime/1","doc":"Extract MIME Type from headers.","ref":"Readability.html#mime/1"},{"type":"function","title":"Example - Readability.mime/1","doc":"iex> mime = Readability.mime(headers_list)\n    \"text/html\"","ref":"Readability.html#mime/1-example"},{"type":"function","title":"Readability.parse/1","doc":"","ref":"Readability.html#parse/1"},{"type":"function","title":"Readability.raw_html/1","doc":"Returns raw HTML binary from `html_tree`.","ref":"Readability.html#raw_html/1"},{"type":"function","title":"Readability.readable_html/1","doc":"Returns attributes, tags cleaned HTML.","ref":"Readability.html#readable_html/1"},{"type":"function","title":"Readability.readable_text/1","doc":"Returns only text binary from `html_tree`.","ref":"Readability.html#readable_text/1"},{"type":"function","title":"Readability.regexes/1","doc":"","ref":"Readability.html#regexes/1"},{"type":"function","title":"Readability.summarize/2","doc":"Summarize the primary readable content of a webpage.","ref":"Readability.html#summarize/2"},{"type":"function","title":"Readability.title/1","doc":"Extract title","ref":"Readability.html#title/1"},{"type":"function","title":"Example - Readability.title/1","doc":"iex> title = Readability.title(html_str)\n    \"Some title in html\"","ref":"Readability.html#title/1-example"},{"type":"type","title":"Readability.headers/0","doc":"","ref":"Readability.html#t:headers/0"},{"type":"type","title":"Readability.html_tree/0","doc":"","ref":"Readability.html#t:html_tree/0"},{"type":"type","title":"Readability.options/0","doc":"","ref":"Readability.html#t:options/0"},{"type":"type","title":"Readability.raw_html/0","doc":"","ref":"Readability.html#t:raw_html/0"},{"type":"type","title":"Readability.url/0","doc":"","ref":"Readability.html#t:url/0"},{"type":"module","title":"Readability.ArticleBuilder","doc":"Build article for readability.","ref":"Readability.ArticleBuilder.html"},{"type":"function","title":"Readability.ArticleBuilder.build/2","doc":"Prepare the article node for display.\n\nClean out any inline styles, iframes, forms, strip extraneous   tags, etc.","ref":"Readability.ArticleBuilder.html#build/2"},{"type":"type","title":"Readability.ArticleBuilder.html_tree/0","doc":"","ref":"Readability.ArticleBuilder.html#t:html_tree/0"},{"type":"type","title":"Readability.ArticleBuilder.options/0","doc":"","ref":"Readability.ArticleBuilder.html#t:options/0"},{"type":"module","title":"Readability.AuthorFinder","doc":"AuthorFinder extracts authors.","ref":"Readability.AuthorFinder.html"},{"type":"function","title":"Readability.AuthorFinder.find/1","doc":"Extract authors.","ref":"Readability.AuthorFinder.html#find/1"},{"type":"function","title":"Readability.AuthorFinder.find_by_meta_tag/1","doc":"","ref":"Readability.AuthorFinder.html#find_by_meta_tag/1"},{"type":"type","title":"Readability.AuthorFinder.html_tree/0","doc":"","ref":"Readability.AuthorFinder.html#t:html_tree/0"},{"type":"module","title":"Readability.Candidate","doc":"Candidate can be article.","ref":"Readability.Candidate.html"},{"type":"module","title":"Readability.Candidate.Cleaner","doc":"Clean HTML tree for prepare candidates.\n\nIt transforms misused tags and removes unlikely candidates.","ref":"Readability.Candidate.Cleaner.html"},{"type":"function","title":"Readability.Candidate.Cleaner.remove_unlikely_tree/1","doc":"Removes unlikely HTML tree.","ref":"Readability.Candidate.Cleaner.html#remove_unlikely_tree/1"},{"type":"function","title":"Readability.Candidate.Cleaner.transform_misused_div_to_p/1","doc":"Transforms misused divs  s that do not contain other block elements into  s.","ref":"Readability.Candidate.Cleaner.html#transform_misused_div_to_p/1"},{"type":"type","title":"Readability.Candidate.Cleaner.html_tree/0","doc":"","ref":"Readability.Candidate.Cleaner.html#t:html_tree/0"},{"type":"module","title":"Readability.Candidate.Scoring","doc":"Score HTML tree.","ref":"Readability.Candidate.Scoring.html"},{"type":"function","title":"Readability.Candidate.Scoring.calc_link_density/1","doc":"","ref":"Readability.Candidate.Scoring.html#calc_link_density/1"},{"type":"function","title":"Readability.Candidate.Scoring.calc_score/2","doc":"Score HTML tree by some algorithm that check children nodes, attributes, link densities, etcs..\n\noptions -> weight_classes :: boolean, calculate weight class.","ref":"Readability.Candidate.Scoring.html#calc_score/2"},{"type":"function","title":"Readability.Candidate.Scoring.class_weight/1","doc":"","ref":"Readability.Candidate.Scoring.html#class_weight/1"},{"type":"type","title":"Readability.Candidate.Scoring.html_tree/0","doc":"","ref":"Readability.Candidate.Scoring.html#t:html_tree/0"},{"type":"type","title":"Readability.Candidate.Scoring.options/0","doc":"","ref":"Readability.Candidate.Scoring.html#t:options/0"},{"type":"module","title":"Readability.CandidateFinder","doc":"The builing and finding candidates  engine.\n\nIt traverses the HTML tree searching, removing, socring nodes.","ref":"Readability.CandidateFinder.html"},{"type":"function","title":"Readability.CandidateFinder.candidate_tag?/1","doc":"Check `html_tree` can be candidate or not.","ref":"Readability.CandidateFinder.html#candidate_tag?/1"},{"type":"function","title":"Readability.CandidateFinder.find/3","doc":"Find candidates that should be meaningful article by analysing nodes.","ref":"Readability.CandidateFinder.html#find/3"},{"type":"function","title":"Readability.CandidateFinder.find_best_candidate/1","doc":"Find the highest score candidate.","ref":"Readability.CandidateFinder.html#find_best_candidate/1"},{"type":"type","title":"Readability.CandidateFinder.html_tree/0","doc":"","ref":"Readability.CandidateFinder.html#t:html_tree/0"},{"type":"type","title":"Readability.CandidateFinder.options/0","doc":"","ref":"Readability.CandidateFinder.html#t:options/0"},{"type":"module","title":"Readability.Helper","doc":"Helpers for parsing, updating, and removing HTML tree.","ref":"Readability.Helper.html"},{"type":"function","title":"Readability.Helper.change_tag/3","doc":"Change existing tags by selector.","ref":"Readability.Helper.html#change_tag/3"},{"type":"function","title":"Readability.Helper.normalize/2","doc":"Normalizes and parses to HTML tree (tuple or list)) from binary HTML.","ref":"Readability.Helper.html#normalize/2"},{"type":"function","title":"Readability.Helper.remove_attrs/2","doc":"Remove html attributes","ref":"Readability.Helper.html#remove_attrs/2"},{"type":"function","title":"Readability.Helper.remove_tag/2","doc":"Removes tags.","ref":"Readability.Helper.html#remove_tag/2"},{"type":"type","title":"Readability.Helper.html_tree/0","doc":"","ref":"Readability.Helper.html#t:html_tree/0"},{"type":"module","title":"Readability.Queries","doc":"Highly-optimized utilities for quick answers about HTML tree","ref":"Readability.Queries.html"},{"type":"function","title":"Readability.Queries.cache_stats_in_attributes/1","doc":"","ref":"Readability.Queries.html#cache_stats_in_attributes/1"},{"type":"function","title":"Readability.Queries.clear_stats_from_attributes/1","doc":"","ref":"Readability.Queries.html#clear_stats_from_attributes/1"},{"type":"function","title":"Readability.Queries.count_character/2","doc":"Finds number of occurences of a given character, much faster than converting to text","ref":"Readability.Queries.html#count_character/2"},{"type":"function","title":"Readability.Queries.find_tag/2","doc":"Finds given tags in HTML tree, much faster than using generic selector","ref":"Readability.Queries.html#find_tag/2"},{"type":"function","title":"Readability.Queries.find_tag_internal/2","doc":"","ref":"Readability.Queries.html#find_tag_internal/2"},{"type":"function","title":"Readability.Queries.text_length/1","doc":"Count only text length.","ref":"Readability.Queries.html#text_length/1"},{"type":"type","title":"Readability.Queries.html_tree/0","doc":"","ref":"Readability.Queries.html#t:html_tree/0"},{"type":"type","title":"Readability.Queries.options/0","doc":"","ref":"Readability.Queries.html#t:options/0"},{"type":"module","title":"Readability.Sanitizer","doc":"Clean an element of all tags of type \"tag\" if they look fishy.\n\n\"Fishy\" is an algorithm based on content length, classnames, link density,\nnumber of images & embeds, etc.","ref":"Readability.Sanitizer.html"},{"type":"function","title":"Readability.Sanitizer.sanitize/3","doc":"Sanitizes article HTML tree.","ref":"Readability.Sanitizer.html#sanitize/3"},{"type":"type","title":"Readability.Sanitizer.html_tree/0","doc":"","ref":"Readability.Sanitizer.html#t:html_tree/0"},{"type":"module","title":"Readability.TitleFinder","doc":"The TitleFinder engine traverses HTML tree searching for finding title.","ref":"Readability.TitleFinder.html"},{"type":"function","title":"Readability.TitleFinder.h_tag_title/2","doc":"Find title from `h` tag.","ref":"Readability.TitleFinder.html#h_tag_title/2"},{"type":"function","title":"Readability.TitleFinder.og_title/1","doc":"Find title from `og:title` property of meta tag.","ref":"Readability.TitleFinder.html#og_title/1"},{"type":"function","title":"Readability.TitleFinder.tag_title/1","doc":"Find title from title tag.","ref":"Readability.TitleFinder.html#tag_title/1"},{"type":"function","title":"Readability.TitleFinder.title/1","doc":"Find proper title.","ref":"Readability.TitleFinder.html#title/1"},{"type":"type","title":"Readability.TitleFinder.html_tree/0","doc":"","ref":"Readability.TitleFinder.html#t:html_tree/0"},{"type":"extras","title":"License","doc":"# Apache License\nVersion 2.0, January 2004\n\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html"},{"type":"extras","title":"1. Definitions. - License","doc":"\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.","ref":"license.html#1-definitions"},{"type":"extras","title":"2. Grant of Copyright License. - License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license"},{"type":"extras","title":"3. Grant of Patent License. - License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including a\ncross-claim or counterclaim in a lawsuit) alleging that the Work or a\nContribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license"},{"type":"extras","title":"4. Redistribution. - License","doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n1. You must give any other recipients of the Work or Derivative Works a copy of\n   this License; and\n\n2. You must cause any modified files to carry prominent notices stating that\n   You changed the files; and\n\n3. You must retain, in the Source form of any Derivative Works that You\n   distribute, all copyright, patent, trademark, and attribution notices from\n   the Source form of the Work, excluding those notices that do not pertain to\n   any part of the Derivative Works; and\n\n4. If the Work includes a \"NOTICE\" text file as part of its distribution, then\n   any Derivative Works that You distribute must include a readable copy of the\n   attribution notices contained within such NOTICE file, excluding those\n   notices that do not pertain to any part of the Derivative Works, in at least\n   one of the following places: within a NOTICE text file distributed as part\n   of the Derivative Works; within the Source form or documentation, if\n   provided along with the Derivative Works; or, within a display generated by\n   the Derivative Works, if and wherever such third-party notices normally\n   appear. The contents of the NOTICE file are for informational purposes only\n   and do not modify the License. You may add Your own attribution notices\n   within Derivative Works that You distribute, alongside or as an addendum to\n   the NOTICE text from the Work, provided that such additional attribution\n   notices cannot be construed as modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.","ref":"license.html#4-redistribution"},{"type":"extras","title":"5. Submission of Contributions. - License","doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.","ref":"license.html#5-submission-of-contributions"},{"type":"extras","title":"6. Trademarks. - License","doc":"This License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.","ref":"license.html#6-trademarks"},{"type":"extras","title":"7. Disclaimer of Warranty. - License","doc":"Unless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE, NON-\nINFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.","ref":"license.html#7-disclaimer-of-warranty"},{"type":"extras","title":"8. Limitation of Liability. - License","doc":"In no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability"},{"type":"extras","title":"9. Accepting Warranty or Additional Liability. - License","doc":"While redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS","ref":"license.html#9-accepting-warranty-or-additional-liability"},{"type":"extras","title":"Overview","doc":"# Readability\n\n[![CI](https://github.com/keepcosmos/readability/actions/workflows/elixir.yml/badge.svg)](https://github.com/keepcosmos/readability/actions/workflows/elixir.yml)\n[![Module Version](https://img.shields.io/hexpm/v/readability.svg)](https://hex.pm/packages/readability)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/readability/)\n[![Total Download](https://img.shields.io/hexpm/dt/readability.svg)](https://hex.pm/packages/readability)\n[![License](https://img.shields.io/hexpm/l/readability.svg)](https://github.com/keepcosmos/readability/blob/master/LICENSE.md)\n[![Coverage Status](https://coveralls.io/repos/github/keepcosmos/readability/badge.svg?branch=master)](https://coveralls.io/github/keepcosmos/readability?branch=master)\n\nReadability is a tool for extracting and curating the primary readable content of a webpage.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"The package can be installed as:\n\nAdd `:readability` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:readability, \"~> 0.12\"}\n  ]\nend\n```\n\nAfter that, run mix deps.get.\n\nNote: Readability requires Elixir 1.10 or higher.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Overview","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Examples - Overview","doc":"##","ref":"readme.html#examples"},{"type":"extras","title":"Just pass a url - Overview","doc":"```elixir\nurl = \"https://medium.com/@kenmazaika/why-im-betting-on-elixir-7c8f847b58\"\nsummary = Readability.summarize(url)\n\nsummary.title\n#=> \"Why I’m betting on Elixir\"\n\nsummary.authors\n#=> [\"Ken Mazaika\"]\n\nsummary.article_html\n#=>\n#      Background:    I’ve spent...\n# ...\n# ...button!    \n\nsummary.article_text\n#=>\n# Background: I’ve spent the past 6 years building web applications in Ruby and.....\n# ...\n# ... value in this article, it would mean a lot to me if you hit the recommend button!\n```\n\n##","ref":"readme.html#just-pass-a-url"},{"type":"extras","title":"From raw html - Overview","doc":"```elixir\n#","ref":"readme.html#from-raw-html"},{"type":"extras","title":"Extract the title. - Overview","doc":"Readability.title(html)\n\n#","ref":"readme.html#extract-the-title"},{"type":"extras","title":"Extract authors. - Overview","doc":"Readability.authors(html)\n\n#","ref":"readme.html#extract-authors"},{"type":"extras","title":"Extract the primary content with transformed html. - Overview","doc":"html\n|> Readability.article\n|> Readability.readable_html\n\n#","ref":"readme.html#extract-the-primary-content-with-transformed-html"},{"type":"extras","title":"Extract only text from the primary content. - Overview","doc":"html\n|> Readability.article\n|> Readability.readable_text\n\n#","ref":"readme.html#extract-only-text-from-the-primary-content"},{"type":"extras","title":"you can extract the primary images with Floki - Overview","doc":"html\n|> Readability.article\n|> Floki.find(\"img\")\n|> Floki.attribute(\"src\")\n```\n\n#","ref":"readme.html#you-can-extract-the-primary-images-with-floki"},{"type":"extras","title":"Options - Overview","doc":"If the result is different from your expectations, you can add options to customize it.\n\n##","ref":"readme.html#options"},{"type":"extras","title":"Example - Overview","doc":"```elixir\nurl = \"https://medium.com/@kenmazaika/why-im-betting-on-elixir-7c8f847b58\"\nsummary = Readability.summarize(url, [clean_conditionally: false])\n```\n\n* `:min_text_length` \\\\\\\\ 25\n* `:remove_unlikely_candidates` \\\\\\\\ true\n* `:weight_classes` \\\\\\\\ true\n* `:clean_conditionally` \\\\\\\\ true\n* `:retry_length` \\\\\\\\ 250\n\n**You can find other algorithm and regex options in `readability.ex`**","ref":"readme.html#example"},{"type":"extras","title":"Test - Overview","doc":"To run the test suite:\n\n    $ mix test","ref":"readme.html#test"},{"type":"extras","title":"Todo - Overview","doc":"* [x] Extract authors\n* [x] More configurable\n* [x] Summarize function\n* [ ] Convert relative paths into absolute paths of `img#src` and `a#href`","ref":"readme.html#todo"},{"type":"extras","title":"Contributions are welcome! - Overview","doc":"Check out [the main features milestone](https://github.com/keepcosmos/readability/milestones) and features of related projects below\n\n**Contributing**\n1. **Fork** the repo on GitHub\n2. **Clone** the project to your own machine\n3. **Commit** changes to your own branch\n4. **Push** your work back up to your fork\n5. Submit a **Pull request** so that we can review your changes\n\nNOTE: Be sure to merge the latest from \"upstream\" before making a pull request!","ref":"readme.html#contributions-are-welcome"},{"type":"extras","title":"Related and Inspired Projects - Overview","doc":"* [readability.js](https://github.com/mozilla/readability) is a standalone version of the readability library used for Firefox Reader View.\n* [newspaper](https://github.com/codelucas/newspaper) is an advanced news extraction, article extraction, and content curation library for Python.\n* [ruby-readability](https://github.com/cantino/ruby-readability) is a tool for extracting the primary readable content of a webpage.","ref":"readme.html#related-and-inspired-projects"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2016 Jaehyun Shin\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}